import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaBadgeColors(typing_extensions.TypedDict, total=False):
    backgroundColor: GoogleTypeColor
    foregroundColor: GoogleTypeColor
    soloColor: GoogleTypeColor

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaBadgeConfig(typing_extensions.TypedDict, total=False):
    color: GoogleTypeColor
    priorityOverride: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaBatchDeleteLabelPermissionsRequest(
    typing_extensions.TypedDict, total=False
):
    requests: _list[GoogleAppsDriveLabelsV2betaDeleteLabelPermissionRequest]
    useAdminAccess: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsRequest(
    typing_extensions.TypedDict, total=False
):
    requests: _list[GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest]
    useAdminAccess: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaBatchUpdateLabelPermissionsResponse(
    typing_extensions.TypedDict, total=False
):
    permissions: _list[GoogleAppsDriveLabelsV2betaLabelPermission]

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDateLimits(typing_extensions.TypedDict, total=False):
    maxValue: GoogleTypeDate
    minValue: GoogleTypeDate

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeleteLabelPermissionRequest(
    typing_extensions.TypedDict, total=False
):
    name: str
    useAdminAccess: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequest(
    typing_extensions.TypedDict, total=False
):
    languageCode: str
    requests: _list[GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestRequest]
    useAdminAccess: bool
    view: typing_extensions.Literal["LABEL_VIEW_BASIC", "LABEL_VIEW_FULL"]
    writeControl: GoogleAppsDriveLabelsV2betaWriteControl

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestCreateFieldRequest(
    typing_extensions.TypedDict, total=False
):
    field: GoogleAppsDriveLabelsV2betaField

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestCreateSelectionChoiceRequest(
    typing_extensions.TypedDict, total=False
):
    choice: GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice
    fieldId: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDeleteFieldRequest(
    typing_extensions.TypedDict, total=False
):
    id: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDeleteSelectionChoiceRequest(
    typing_extensions.TypedDict, total=False
):
    fieldId: str
    id: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDisableFieldRequest(
    typing_extensions.TypedDict, total=False
):
    disabledPolicy: GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy
    id: str
    updateMask: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDisableSelectionChoiceRequest(
    typing_extensions.TypedDict, total=False
):
    disabledPolicy: GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy
    fieldId: str
    id: str
    updateMask: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestEnableFieldRequest(
    typing_extensions.TypedDict, total=False
):
    id: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestEnableSelectionChoiceRequest(
    typing_extensions.TypedDict, total=False
):
    fieldId: str
    id: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestRequest(
    typing_extensions.TypedDict, total=False
):
    createField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestCreateFieldRequest
    createSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestCreateSelectionChoiceRequest
    deleteField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDeleteFieldRequest
    deleteSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDeleteSelectionChoiceRequest
    disableField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDisableFieldRequest
    disableSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestDisableSelectionChoiceRequest
    enableField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestEnableFieldRequest
    enableSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestEnableSelectionChoiceRequest
    updateField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateFieldPropertiesRequest
    updateFieldType: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateFieldTypeRequest
    updateLabel: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateLabelPropertiesRequest
    updateSelectionChoiceProperties: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateSelectionChoicePropertiesRequest

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateFieldPropertiesRequest(
    typing_extensions.TypedDict, total=False
):
    id: str
    properties: GoogleAppsDriveLabelsV2betaFieldProperties
    updateMask: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateFieldTypeRequest(
    typing_extensions.TypedDict, total=False
):
    dateOptions: GoogleAppsDriveLabelsV2betaFieldDateOptions
    id: str
    integerOptions: GoogleAppsDriveLabelsV2betaFieldIntegerOptions
    longTextOptions: GoogleAppsDriveLabelsV2betaFieldLongTextOptions
    selectionOptions: GoogleAppsDriveLabelsV2betaFieldSelectionOptions
    textOptions: GoogleAppsDriveLabelsV2betaFieldTextOptions
    updateMask: str
    userOptions: GoogleAppsDriveLabelsV2betaFieldUserOptions

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateLabelPropertiesRequest(
    typing_extensions.TypedDict, total=False
):
    properties: GoogleAppsDriveLabelsV2betaLabelProperties
    updateMask: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelRequestUpdateSelectionChoicePropertiesRequest(
    typing_extensions.TypedDict, total=False
):
    fieldId: str
    id: str
    properties: GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
    updateMask: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponse(
    typing_extensions.TypedDict, total=False
):
    responses: _list[GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseResponse]
    updatedLabel: GoogleAppsDriveLabelsV2betaLabel

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseCreateFieldResponse(
    typing_extensions.TypedDict, total=False
):
    id: str
    priority: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseCreateSelectionChoiceResponse(
    typing_extensions.TypedDict, total=False
):
    fieldId: str
    id: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDeleteFieldResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDeleteSelectionChoiceResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDisableFieldResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDisableSelectionChoiceResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseEnableFieldResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseEnableSelectionChoiceResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseResponse(
    typing_extensions.TypedDict, total=False
):
    createField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseCreateFieldResponse
    createSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseCreateSelectionChoiceResponse
    deleteField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDeleteFieldResponse
    deleteSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDeleteSelectionChoiceResponse
    disableField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDisableFieldResponse
    disableSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseDisableSelectionChoiceResponse
    enableField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseEnableFieldResponse
    enableSelectionChoice: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseEnableSelectionChoiceResponse
    updateField: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateFieldPropertiesResponse
    updateFieldType: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateFieldTypeResponse
    updateLabel: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateLabelPropertiesResponse
    updateSelectionChoiceProperties: GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateSelectionChoicePropertiesResponse

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateFieldPropertiesResponse(
    typing_extensions.TypedDict, total=False
):
    priority: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateFieldTypeResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateLabelPropertiesResponse(
    typing_extensions.TypedDict, total=False
): ...

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDeltaUpdateLabelResponseUpdateSelectionChoicePropertiesResponse(
    typing_extensions.TypedDict, total=False
):
    priority: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaDisableLabelRequest(
    typing_extensions.TypedDict, total=False
):
    disabledPolicy: GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy
    languageCode: str
    updateMask: str
    useAdminAccess: bool
    writeControl: GoogleAppsDriveLabelsV2betaWriteControl

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaEnableLabelRequest(
    typing_extensions.TypedDict, total=False
):
    languageCode: str
    useAdminAccess: bool
    writeControl: GoogleAppsDriveLabelsV2betaWriteControl

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaField(typing_extensions.TypedDict, total=False):
    appliedCapabilities: GoogleAppsDriveLabelsV2betaFieldAppliedCapabilities
    createTime: str
    creator: GoogleAppsDriveLabelsV2betaUserInfo
    dateOptions: GoogleAppsDriveLabelsV2betaFieldDateOptions
    disableTime: str
    disabler: GoogleAppsDriveLabelsV2betaUserInfo
    displayHints: GoogleAppsDriveLabelsV2betaFieldDisplayHints
    id: str
    integerOptions: GoogleAppsDriveLabelsV2betaFieldIntegerOptions
    lifecycle: GoogleAppsDriveLabelsV2betaLifecycle
    lockStatus: GoogleAppsDriveLabelsV2betaLockStatus
    properties: GoogleAppsDriveLabelsV2betaFieldProperties
    publisher: GoogleAppsDriveLabelsV2betaUserInfo
    queryKey: str
    schemaCapabilities: GoogleAppsDriveLabelsV2betaFieldSchemaCapabilities
    selectionOptions: GoogleAppsDriveLabelsV2betaFieldSelectionOptions
    textOptions: GoogleAppsDriveLabelsV2betaFieldTextOptions
    updateTime: str
    updater: GoogleAppsDriveLabelsV2betaUserInfo
    userOptions: GoogleAppsDriveLabelsV2betaFieldUserOptions

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldAppliedCapabilities(
    typing_extensions.TypedDict, total=False
):
    canRead: bool
    canSearch: bool
    canWrite: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldDateOptions(
    typing_extensions.TypedDict, total=False
):
    dateFormat: str
    dateFormatType: typing_extensions.Literal[
        "DATE_FORMAT_UNSPECIFIED", "LONG_DATE", "SHORT_DATE"
    ]
    maxValue: GoogleTypeDate
    minValue: GoogleTypeDate

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldDisplayHints(
    typing_extensions.TypedDict, total=False
):
    disabled: bool
    hiddenInSearch: bool
    required: bool
    shownInApply: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldIntegerOptions(
    typing_extensions.TypedDict, total=False
):
    maxValue: str
    minValue: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldLimits(typing_extensions.TypedDict, total=False):
    dateLimits: GoogleAppsDriveLabelsV2betaDateLimits
    integerLimits: GoogleAppsDriveLabelsV2betaIntegerLimits
    longTextLimits: GoogleAppsDriveLabelsV2betaLongTextLimits
    maxDescriptionLength: int
    maxDisplayNameLength: int
    maxIdLength: int
    selectionLimits: GoogleAppsDriveLabelsV2betaSelectionLimits
    textLimits: GoogleAppsDriveLabelsV2betaTextLimits
    userLimits: GoogleAppsDriveLabelsV2betaUserLimits

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldListOptions(
    typing_extensions.TypedDict, total=False
):
    maxEntries: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldLongTextOptions(
    typing_extensions.TypedDict, total=False
):
    maxLength: int
    minLength: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldProperties(
    typing_extensions.TypedDict, total=False
):
    displayName: str
    insertBeforeField: str
    required: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSchemaCapabilities(
    typing_extensions.TypedDict, total=False
):
    canDelete: bool
    canDisable: bool
    canEnable: bool
    canUpdate: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSelectionOptions(
    typing_extensions.TypedDict, total=False
):
    choices: _list[GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice]
    listOptions: GoogleAppsDriveLabelsV2betaFieldListOptions

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoice(
    typing_extensions.TypedDict, total=False
):
    appliedCapabilities: GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities
    createTime: str
    creator: GoogleAppsDriveLabelsV2betaUserInfo
    disableTime: str
    disabler: GoogleAppsDriveLabelsV2betaUserInfo
    displayHints: GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceDisplayHints
    id: str
    lifecycle: GoogleAppsDriveLabelsV2betaLifecycle
    lockStatus: GoogleAppsDriveLabelsV2betaLockStatus
    properties: GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties
    publishTime: str
    publisher: GoogleAppsDriveLabelsV2betaUserInfo
    schemaCapabilities: GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceSchemaCapabilities
    updateTime: str
    updater: GoogleAppsDriveLabelsV2betaUserInfo

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceAppliedCapabilities(
    typing_extensions.TypedDict, total=False
):
    canRead: bool
    canSearch: bool
    canSelect: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceDisplayHints(
    typing_extensions.TypedDict, total=False
):
    badgeColors: GoogleAppsDriveLabelsV2betaBadgeColors
    badgePriority: str
    darkBadgeColors: GoogleAppsDriveLabelsV2betaBadgeColors
    disabled: bool
    hiddenInSearch: bool
    shownInApply: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceProperties(
    typing_extensions.TypedDict, total=False
):
    badgeConfig: GoogleAppsDriveLabelsV2betaBadgeConfig
    description: str
    displayName: str
    insertBeforeChoice: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldSelectionOptionsChoiceSchemaCapabilities(
    typing_extensions.TypedDict, total=False
):
    canDelete: bool
    canDisable: bool
    canEnable: bool
    canUpdate: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldTextOptions(
    typing_extensions.TypedDict, total=False
):
    maxLength: int
    minLength: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaFieldUserOptions(
    typing_extensions.TypedDict, total=False
):
    listOptions: GoogleAppsDriveLabelsV2betaFieldListOptions

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaIntegerLimits(
    typing_extensions.TypedDict, total=False
):
    maxValue: str
    minValue: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabel(typing_extensions.TypedDict, total=False):
    appliedCapabilities: GoogleAppsDriveLabelsV2betaLabelAppliedCapabilities
    appliedLabelPolicy: GoogleAppsDriveLabelsV2betaLabelAppliedLabelPolicy
    createTime: str
    creator: GoogleAppsDriveLabelsV2betaUserInfo
    disableTime: str
    disabler: GoogleAppsDriveLabelsV2betaUserInfo
    displayHints: GoogleAppsDriveLabelsV2betaLabelDisplayHints
    fields: _list[GoogleAppsDriveLabelsV2betaField]
    id: str
    labelType: typing_extensions.Literal["LABEL_TYPE_UNSPECIFIED", "SHARED", "ADMIN"]
    learnMoreUri: str
    lifecycle: GoogleAppsDriveLabelsV2betaLifecycle
    lockStatus: GoogleAppsDriveLabelsV2betaLockStatus
    name: str
    properties: GoogleAppsDriveLabelsV2betaLabelProperties
    publishTime: str
    publisher: GoogleAppsDriveLabelsV2betaUserInfo
    revisionCreateTime: str
    revisionCreator: GoogleAppsDriveLabelsV2betaUserInfo
    revisionId: str
    schemaCapabilities: GoogleAppsDriveLabelsV2betaLabelSchemaCapabilities

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelAppliedCapabilities(
    typing_extensions.TypedDict, total=False
):
    canApply: bool
    canRead: bool
    canRemove: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelAppliedLabelPolicy(
    typing_extensions.TypedDict, total=False
):
    copyMode: typing_extensions.Literal[
        "COPY_MODE_UNSPECIFIED", "DO_NOT_COPY", "ALWAYS_COPY", "COPY_APPLIABLE"
    ]

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelDisplayHints(
    typing_extensions.TypedDict, total=False
):
    disabled: bool
    hiddenInSearch: bool
    priority: str
    shownInApply: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelLimits(typing_extensions.TypedDict, total=False):
    fieldLimits: GoogleAppsDriveLabelsV2betaFieldLimits
    maxDeletedFields: int
    maxDescriptionLength: int
    maxDraftRevisions: int
    maxFields: int
    maxTitleLength: int
    name: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelLock(typing_extensions.TypedDict, total=False):
    capabilities: GoogleAppsDriveLabelsV2betaLabelLockCapabilities
    choiceId: str
    createTime: str
    creator: GoogleAppsDriveLabelsV2betaUserInfo
    deleteTime: str
    fieldId: str
    name: str
    policyUri: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DELETING"]

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelLockCapabilities(
    typing_extensions.TypedDict, total=False
):
    canViewPolicy: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelPermission(
    typing_extensions.TypedDict, total=False
):
    audience: str
    email: str
    group: str
    name: str
    person: str
    role: typing_extensions.Literal[
        "LABEL_ROLE_UNSPECIFIED", "READER", "APPLIER", "ORGANIZER", "EDITOR"
    ]

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelProperties(
    typing_extensions.TypedDict, total=False
):
    description: str
    title: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLabelSchemaCapabilities(
    typing_extensions.TypedDict, total=False
):
    canDelete: bool
    canDisable: bool
    canEnable: bool
    canUpdate: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLifecycle(typing_extensions.TypedDict, total=False):
    disabledPolicy: GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy
    hasUnpublishedChanges: bool
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED", "UNPUBLISHED_DRAFT", "PUBLISHED", "DISABLED", "DELETED"
    ]

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLifecycleDisabledPolicy(
    typing_extensions.TypedDict, total=False
):
    hideInSearch: bool
    showInApply: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLabelLocksResponse(
    typing_extensions.TypedDict, total=False
):
    labelLocks: _list[GoogleAppsDriveLabelsV2betaLabelLock]
    nextPageToken: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLabelPermissionsResponse(
    typing_extensions.TypedDict, total=False
):
    labelPermissions: _list[GoogleAppsDriveLabelsV2betaLabelPermission]
    nextPageToken: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLabelsResponse(
    typing_extensions.TypedDict, total=False
):
    labels: _list[GoogleAppsDriveLabelsV2betaLabel]
    nextPageToken: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaListLimits(typing_extensions.TypedDict, total=False):
    maxEntries: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLockStatus(typing_extensions.TypedDict, total=False):
    locked: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaLongTextLimits(
    typing_extensions.TypedDict, total=False
):
    maxLength: int
    minLength: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaPublishLabelRequest(
    typing_extensions.TypedDict, total=False
):
    languageCode: str
    useAdminAccess: bool
    writeControl: GoogleAppsDriveLabelsV2betaWriteControl

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaSelectionLimits(
    typing_extensions.TypedDict, total=False
):
    listLimits: GoogleAppsDriveLabelsV2betaListLimits
    maxChoices: int
    maxDeletedChoices: int
    maxDisplayNameLength: int
    maxIdLength: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaTextLimits(typing_extensions.TypedDict, total=False):
    maxLength: int
    minLength: int

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaUpdateLabelCopyModeRequest(
    typing_extensions.TypedDict, total=False
):
    copyMode: typing_extensions.Literal[
        "COPY_MODE_UNSPECIFIED", "DO_NOT_COPY", "ALWAYS_COPY", "COPY_APPLIABLE"
    ]
    languageCode: str
    useAdminAccess: bool
    view: typing_extensions.Literal["LABEL_VIEW_BASIC", "LABEL_VIEW_FULL"]

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaUpdateLabelPermissionRequest(
    typing_extensions.TypedDict, total=False
):
    labelPermission: GoogleAppsDriveLabelsV2betaLabelPermission
    parent: str
    useAdminAccess: bool

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaUserCapabilities(
    typing_extensions.TypedDict, total=False
):
    canAccessLabelManager: bool
    canAdministrateLabels: bool
    canCreateAdminLabels: bool
    canCreateSharedLabels: bool
    name: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaUserInfo(typing_extensions.TypedDict, total=False):
    person: str

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaUserLimits(typing_extensions.TypedDict, total=False):
    listLimits: GoogleAppsDriveLabelsV2betaListLimits

@typing.type_check_only
class GoogleAppsDriveLabelsV2betaWriteControl(typing_extensions.TypedDict, total=False):
    requiredRevisionId: str

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GoogleTypeColor(typing_extensions.TypedDict, total=False):
    alpha: float
    blue: float
    green: float
    red: float

@typing.type_check_only
class GoogleTypeDate(typing_extensions.TypedDict, total=False):
    day: int
    month: int
    year: int



import typing

import typing_extensions

_list = list
AlternativeSearchResponse = typing_extensions.TypedDict(
    "AlternativeSearchResponse",
    {
        "@context": typing.Any,
        "@type": typing.Any,
        "itemListElement": _list[typing.Any],
    },
    total=False,
)

@typing.type_check_only
class SearchResponse(AlternativeSearchResponse): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class MyBusinessQAndAResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class LocationsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class QuestionsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AnswersResource(googleapiclient.discovery.Resource):
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    orderBy: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListAnswersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListAnswersResponseHttpRequest,
                    previous_response: ListAnswersResponse,
                ) -> ListAnswersResponseHttpRequest | None: ...
                def upsert(
                    self,
                    *,
                    parent: str,
                    body: UpsertAnswerRequest = ...,
                    **kwargs: typing.Any
                ) -> AnswerHttpRequest: ...

            def create(
                self, *, parent: str, body: Question = ..., **kwargs: typing.Any
            ) -> QuestionHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                answersPerQuestion: int = ...,
                filter: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListQuestionsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListQuestionsResponseHttpRequest,
                previous_response: ListQuestionsResponse,
            ) -> ListQuestionsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Question = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> QuestionHttpRequest: ...
            def answers(self) -> AnswersResource: ...

        def questions(self) -> QuestionsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def locations(self) -> LocationsResource: ...

@typing.type_check_only
class AnswerHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Answer: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListAnswersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAnswersResponse: ...

@typing.type_check_only
class ListQuestionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListQuestionsResponse: ...

@typing.type_check_only
class QuestionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Question: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AliasContext(typing_extensions.TypedDict, total=False):
    kind: typing_extensions.Literal["ANY", "FIXED", "MOVABLE", "OTHER"]
    name: str

@typing.type_check_only
class Breakpoint(typing_extensions.TypedDict, total=False):
    action: typing_extensions.Literal["CAPTURE", "LOG"]
    canaryExpireTime: str
    condition: str
    createTime: str
    evaluatedExpressions: _list[Variable]
    expressions: _list[str]
    finalTime: str
    id: str
    isFinalState: bool
    labels: dict[str, typing.Any]
    location: SourceLocation
    logLevel: typing_extensions.Literal["INFO", "WARNING", "ERROR"]
    logMessageFormat: str
    stackFrames: _list[StackFrame]
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "STATE_CANARY_PENDING_AGENTS",
        "STATE_CANARY_ACTIVE",
        "STATE_ROLLING_TO_ALL",
        "STATE_IS_FINAL",
    ]
    status: StatusMessage
    userEmail: str
    variableTable: _list[Variable]

@typing.type_check_only
class CloudRepoSourceContext(typing_extensions.TypedDict, total=False):
    aliasContext: AliasContext
    aliasName: str
    repoId: RepoId
    revisionId: str

@typing.type_check_only
class CloudWorkspaceId(typing_extensions.TypedDict, total=False):
    name: str
    repoId: RepoId

@typing.type_check_only
class CloudWorkspaceSourceContext(typing_extensions.TypedDict, total=False):
    snapshotId: str
    workspaceId: CloudWorkspaceId

@typing.type_check_only
class Debuggee(typing_extensions.TypedDict, total=False):
    agentVersion: str
    canaryMode: typing_extensions.Literal[
        "CANARY_MODE_UNSPECIFIED",
        "CANARY_MODE_ALWAYS_ENABLED",
        "CANARY_MODE_ALWAYS_DISABLED",
        "CANARY_MODE_DEFAULT_ENABLED",
        "CANARY_MODE_DEFAULT_DISABLED",
    ]
    description: str
    extSourceContexts: _list[ExtendedSourceContext]
    id: str
    isDisabled: bool
    isInactive: bool
    labels: dict[str, typing.Any]
    project: str
    sourceContexts: _list[SourceContext]
    status: StatusMessage
    uniquifier: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ExtendedSourceContext(typing_extensions.TypedDict, total=False):
    context: SourceContext
    labels: dict[str, typing.Any]

@typing.type_check_only
class FormatMessage(typing_extensions.TypedDict, total=False):
    format: str
    parameters: _list[str]

@typing.type_check_only
class GerritSourceContext(typing_extensions.TypedDict, total=False):
    aliasContext: AliasContext
    aliasName: str
    gerritProject: str
    hostUri: str
    revisionId: str

@typing.type_check_only
class GetBreakpointResponse(typing_extensions.TypedDict, total=False):
    breakpoint: Breakpoint

@typing.type_check_only
class GitSourceContext(typing_extensions.TypedDict, total=False):
    revisionId: str
    url: str

@typing.type_check_only
class ListActiveBreakpointsResponse(typing_extensions.TypedDict, total=False):
    breakpoints: _list[Breakpoint]
    nextWaitToken: str
    waitExpired: bool

@typing.type_check_only
class ListBreakpointsResponse(typing_extensions.TypedDict, total=False):
    breakpoints: _list[Breakpoint]
    nextWaitToken: str

@typing.type_check_only
class ListDebuggeesResponse(typing_extensions.TypedDict, total=False):
    debuggees: _list[Debuggee]

@typing.type_check_only
class ProjectRepoId(typing_extensions.TypedDict, total=False):
    projectId: str
    repoName: str

@typing.type_check_only
class RegisterDebuggeeRequest(typing_extensions.TypedDict, total=False):
    debuggee: Debuggee

@typing.type_check_only
class RegisterDebuggeeResponse(typing_extensions.TypedDict, total=False):
    agentId: str
    debuggee: Debuggee

@typing.type_check_only
class RepoId(typing_extensions.TypedDict, total=False):
    projectRepoId: ProjectRepoId
    uid: str

@typing.type_check_only
class SetBreakpointResponse(typing_extensions.TypedDict, total=False):
    breakpoint: Breakpoint

@typing.type_check_only
class SourceContext(typing_extensions.TypedDict, total=False):
    cloudRepo: CloudRepoSourceContext
    cloudWorkspace: CloudWorkspaceSourceContext
    gerrit: GerritSourceContext
    git: GitSourceContext

@typing.type_check_only
class SourceLocation(typing_extensions.TypedDict, total=False):
    column: int
    line: int
    path: str

@typing.type_check_only
class StackFrame(typing_extensions.TypedDict, total=False):
    arguments: _list[Variable]
    function: str
    locals: _list[Variable]
    location: SourceLocation

@typing.type_check_only
class StatusMessage(typing_extensions.TypedDict, total=False):
    description: FormatMessage
    isError: bool
    refersTo: typing_extensions.Literal[
        "UNSPECIFIED",
        "BREAKPOINT_SOURCE_LOCATION",
        "BREAKPOINT_CONDITION",
        "BREAKPOINT_EXPRESSION",
        "BREAKPOINT_AGE",
        "BREAKPOINT_CANARY_FAILED",
        "VARIABLE_NAME",
        "VARIABLE_VALUE",
    ]

@typing.type_check_only
class UpdateActiveBreakpointRequest(typing_extensions.TypedDict, total=False):
    breakpoint: Breakpoint

@typing.type_check_only
class UpdateActiveBreakpointResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Variable(typing_extensions.TypedDict, total=False):
    members: _list[Variable]
    name: str
    status: StatusMessage
    type: str
    value: str
    varTableIndex: int



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class RemoteBuildExecutionResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class InstancesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class WorkerpoolsResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateWorkerPoolRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPoolHttpRequest: ...
                def list(
                    self, *, parent: str, filter: str = ..., **kwargs: typing.Any
                ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsResponseHttpRequest: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateWorkerPoolRequest = ...,
                    **kwargs: typing.Any
                ) -> GoogleLongrunningOperationHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstanceHttpRequest: ...
            def list(
                self, *, parent: str, **kwargs: typing.Any
            ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesResponseHttpRequest: ...
            def patch(
                self,
                *,
                name: str,
                body: GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance = ...,
                loggingEnabled: bool = ...,
                name1: str = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...
            def workerpools(self) -> WorkerpoolsResource: ...

        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> GoogleLongrunningOperationHttpRequest: ...

        def instances(self) -> InstancesResource: ...
        def operations(self) -> OperationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstanceHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance: ...

@typing.type_check_only
class GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaListInstancesResponse: ...

@typing.type_check_only
class GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaListWorkerPoolsResponse: ...

@typing.type_check_only
class GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPoolHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool: ...

@typing.type_check_only
class GoogleLongrunningOperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GoogleLongrunningOperation: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class AuthorizedBuyersMarketplaceResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class BiddersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class FinalizedDealsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListFinalizedDealsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListFinalizedDealsResponseHttpRequest,
                previous_response: ListFinalizedDealsResponse,
            ) -> ListFinalizedDealsResponseHttpRequest | None: ...

        def finalizedDeals(self) -> FinalizedDealsResource: ...

    @typing.type_check_only
    class BuyersResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class AuctionPackagesResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> AuctionPackageHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAuctionPackagesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAuctionPackagesResponseHttpRequest,
                previous_response: ListAuctionPackagesResponse,
            ) -> ListAuctionPackagesResponseHttpRequest | None: ...
            def subscribe(
                self,
                *,
                name: str,
                body: SubscribeAuctionPackageRequest = ...,
                **kwargs: typing.Any
            ) -> AuctionPackageHttpRequest: ...
            def subscribeClients(
                self,
                *,
                auctionPackage: str,
                body: SubscribeClientsRequest = ...,
                **kwargs: typing.Any
            ) -> AuctionPackageHttpRequest: ...
            def unsubscribe(
                self,
                *,
                name: str,
                body: UnsubscribeAuctionPackageRequest = ...,
                **kwargs: typing.Any
            ) -> AuctionPackageHttpRequest: ...
            def unsubscribeClients(
                self,
                *,
                auctionPackage: str,
                body: UnsubscribeClientsRequest = ...,
                **kwargs: typing.Any
            ) -> AuctionPackageHttpRequest: ...

        @typing.type_check_only
        class ClientsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class UsersResource(googleapiclient.discovery.Resource):
                def activate(
                    self,
                    *,
                    name: str,
                    body: ActivateClientUserRequest = ...,
                    **kwargs: typing.Any
                ) -> ClientUserHttpRequest: ...
                def create(
                    self, *, parent: str, body: ClientUser = ..., **kwargs: typing.Any
                ) -> ClientUserHttpRequest: ...
                def deactivate(
                    self,
                    *,
                    name: str,
                    body: DeactivateClientUserRequest = ...,
                    **kwargs: typing.Any
                ) -> ClientUserHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> ClientUserHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListClientUsersResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListClientUsersResponseHttpRequest,
                    previous_response: ListClientUsersResponse,
                ) -> ListClientUsersResponseHttpRequest | None: ...

            def activate(
                self,
                *,
                name: str,
                body: ActivateClientRequest = ...,
                **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def create(
                self, *, parent: str, body: Client = ..., **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def deactivate(
                self,
                *,
                name: str,
                body: DeactivateClientRequest = ...,
                **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> ClientHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListClientsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListClientsResponseHttpRequest,
                previous_response: ListClientsResponse,
            ) -> ListClientsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Client = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> ClientHttpRequest: ...
            def users(self) -> UsersResource: ...

        @typing.type_check_only
        class FinalizedDealsResource(googleapiclient.discovery.Resource):
            def addCreative(
                self, *, deal: str, body: AddCreativeRequest = ..., **kwargs: typing.Any
            ) -> FinalizedDealHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> FinalizedDealHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListFinalizedDealsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListFinalizedDealsResponseHttpRequest,
                previous_response: ListFinalizedDealsResponse,
            ) -> ListFinalizedDealsResponseHttpRequest | None: ...
            def pause(
                self,
                *,
                name: str,
                body: PauseFinalizedDealRequest = ...,
                **kwargs: typing.Any
            ) -> FinalizedDealHttpRequest: ...
            def resume(
                self,
                *,
                name: str,
                body: ResumeFinalizedDealRequest = ...,
                **kwargs: typing.Any
            ) -> FinalizedDealHttpRequest: ...
            def setReadyToServe(
                self,
                *,
                deal: str,
                body: SetReadyToServeRequest = ...,
                **kwargs: typing.Any
            ) -> FinalizedDealHttpRequest: ...

        @typing.type_check_only
        class ProposalsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class DealsResource(googleapiclient.discovery.Resource):
                def batchUpdate(
                    self,
                    *,
                    parent: str,
                    body: BatchUpdateDealsRequest = ...,
                    **kwargs: typing.Any
                ) -> BatchUpdateDealsResponseHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> DealHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListDealsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListDealsResponseHttpRequest,
                    previous_response: ListDealsResponse,
                ) -> ListDealsResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Deal = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> DealHttpRequest: ...

            def accept(
                self,
                *,
                name: str,
                body: AcceptProposalRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def addNote(
                self, *, proposal: str, body: AddNoteRequest = ..., **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def cancelNegotiation(
                self,
                *,
                proposal: str,
                body: CancelNegotiationRequest = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListProposalsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListProposalsResponseHttpRequest,
                previous_response: ListProposalsResponse,
            ) -> ListProposalsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                name: str,
                body: Proposal = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def sendRfp(
                self, *, buyer: str, body: SendRfpRequest = ..., **kwargs: typing.Any
            ) -> ProposalHttpRequest: ...
            def deals(self) -> DealsResource: ...

        @typing.type_check_only
        class PublisherProfilesResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> PublisherProfileHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListPublisherProfilesResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListPublisherProfilesResponseHttpRequest,
                previous_response: ListPublisherProfilesResponse,
            ) -> ListPublisherProfilesResponseHttpRequest | None: ...

        def auctionPackages(self) -> AuctionPackagesResource: ...
        def clients(self) -> ClientsResource: ...
        def finalizedDeals(self) -> FinalizedDealsResource: ...
        def proposals(self) -> ProposalsResource: ...
        def publisherProfiles(self) -> PublisherProfilesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def bidders(self) -> BiddersResource: ...
    def buyers(self) -> BuyersResource: ...

@typing.type_check_only
class AuctionPackageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AuctionPackage: ...

@typing.type_check_only
class BatchUpdateDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchUpdateDealsResponse: ...

@typing.type_check_only
class ClientHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Client: ...

@typing.type_check_only
class ClientUserHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClientUser: ...

@typing.type_check_only
class DealHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Deal: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class FinalizedDealHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FinalizedDeal: ...

@typing.type_check_only
class ListAuctionPackagesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAuctionPackagesResponse: ...

@typing.type_check_only
class ListClientUsersResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientUsersResponse: ...

@typing.type_check_only
class ListClientsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListClientsResponse: ...

@typing.type_check_only
class ListDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDealsResponse: ...

@typing.type_check_only
class ListFinalizedDealsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListFinalizedDealsResponse: ...

@typing.type_check_only
class ListProposalsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListProposalsResponse: ...

@typing.type_check_only
class ListPublisherProfilesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListPublisherProfilesResponse: ...

@typing.type_check_only
class ProposalHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Proposal: ...

@typing.type_check_only
class PublisherProfileHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PublisherProfile: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Api(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    availability: str
    createTime: str
    description: str
    displayName: str
    labels: dict[str, typing.Any]
    name: str
    recommendedDeployment: str
    recommendedVersion: str
    updateTime: str

@typing.type_check_only
class ApiDeployment(typing_extensions.TypedDict, total=False):
    accessGuidance: str
    annotations: dict[str, typing.Any]
    apiSpecRevision: str
    createTime: str
    description: str
    displayName: str
    endpointUri: str
    externalChannelUri: str
    intendedAudience: str
    labels: dict[str, typing.Any]
    name: str
    revisionCreateTime: str
    revisionId: str
    revisionUpdateTime: str

@typing.type_check_only
class ApiSpec(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    contents: str
    createTime: str
    description: str
    filename: str
    hash: str
    labels: dict[str, typing.Any]
    mimeType: str
    name: str
    revisionCreateTime: str
    revisionId: str
    revisionUpdateTime: str
    sizeBytes: int
    sourceUri: str

@typing.type_check_only
class ApiVersion(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    createTime: str
    description: str
    displayName: str
    labels: dict[str, typing.Any]
    name: str
    state: str
    updateTime: str

@typing.type_check_only
class Artifact(typing_extensions.TypedDict, total=False):
    contents: str
    createTime: str
    hash: str
    mimeType: str
    name: str
    sizeBytes: int
    updateTime: str

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Config(typing_extensions.TypedDict, total=False):
    cmekKeyName: str
    location: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class HttpBody(typing_extensions.TypedDict, total=False):
    contentType: str
    data: str
    extensions: _list[dict[str, typing.Any]]

@typing.type_check_only
class Instance(typing_extensions.TypedDict, total=False):
    config: Config
    createTime: str
    name: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "INACTIVE",
        "CREATING",
        "ACTIVE",
        "UPDATING",
        "DELETING",
        "FAILED",
    ]
    stateMessage: str
    updateTime: str

@typing.type_check_only
class ListApiDeploymentRevisionsResponse(typing_extensions.TypedDict, total=False):
    apiDeployments: _list[ApiDeployment]
    nextPageToken: str

@typing.type_check_only
class ListApiDeploymentsResponse(typing_extensions.TypedDict, total=False):
    apiDeployments: _list[ApiDeployment]
    nextPageToken: str

@typing.type_check_only
class ListApiSpecRevisionsResponse(typing_extensions.TypedDict, total=False):
    apiSpecs: _list[ApiSpec]
    nextPageToken: str

@typing.type_check_only
class ListApiSpecsResponse(typing_extensions.TypedDict, total=False):
    apiSpecs: _list[ApiSpec]
    nextPageToken: str

@typing.type_check_only
class ListApiVersionsResponse(typing_extensions.TypedDict, total=False):
    apiVersions: _list[ApiVersion]
    nextPageToken: str

@typing.type_check_only
class ListApisResponse(typing_extensions.TypedDict, total=False):
    apis: _list[Api]
    nextPageToken: str

@typing.type_check_only
class ListArtifactsResponse(typing_extensions.TypedDict, total=False):
    artifacts: _list[Artifact]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    cancellationRequested: bool
    createTime: str
    endTime: str
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class RollbackApiDeploymentRequest(typing_extensions.TypedDict, total=False):
    revisionId: str

@typing.type_check_only
class RollbackApiSpecRequest(typing_extensions.TypedDict, total=False):
    revisionId: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TagApiDeploymentRevisionRequest(typing_extensions.TypedDict, total=False):
    tag: str

@typing.type_check_only
class TagApiSpecRevisionRequest(typing_extensions.TypedDict, total=False):
    tag: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class BatchDocumentInputConfig(typing_extensions.TypedDict, total=False):
    gcsSource: GcsSource

@typing.type_check_only
class BatchDocumentOutputConfig(typing_extensions.TypedDict, total=False):
    gcsDestination: GcsDestination

@typing.type_check_only
class BatchTranslateDocumentRequest(typing_extensions.TypedDict, total=False):
    formatConversions: dict[str, typing.Any]
    glossaries: dict[str, typing.Any]
    inputConfigs: _list[BatchDocumentInputConfig]
    models: dict[str, typing.Any]
    outputConfig: BatchDocumentOutputConfig
    sourceLanguageCode: str
    targetLanguageCodes: _list[str]

@typing.type_check_only
class BatchTranslateTextRequest(typing_extensions.TypedDict, total=False):
    glossaries: dict[str, typing.Any]
    inputConfigs: _list[InputConfig]
    labels: dict[str, typing.Any]
    models: dict[str, typing.Any]
    outputConfig: OutputConfig
    sourceLanguageCode: str
    targetLanguageCodes: _list[str]

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DetectLanguageRequest(typing_extensions.TypedDict, total=False):
    content: str
    labels: dict[str, typing.Any]
    mimeType: str
    model: str

@typing.type_check_only
class DetectLanguageResponse(typing_extensions.TypedDict, total=False):
    languages: _list[DetectedLanguage]

@typing.type_check_only
class DetectedLanguage(typing_extensions.TypedDict, total=False):
    confidence: float
    languageCode: str

@typing.type_check_only
class DocumentInputConfig(typing_extensions.TypedDict, total=False):
    content: str
    gcsSource: GcsSource
    mimeType: str

@typing.type_check_only
class DocumentOutputConfig(typing_extensions.TypedDict, total=False):
    gcsDestination: GcsDestination
    mimeType: str

@typing.type_check_only
class DocumentTranslation(typing_extensions.TypedDict, total=False):
    byteStreamOutputs: _list[str]
    detectedLanguageCode: str
    mimeType: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GcsDestination(typing_extensions.TypedDict, total=False):
    outputUriPrefix: str

@typing.type_check_only
class GcsSource(typing_extensions.TypedDict, total=False):
    inputUri: str

@typing.type_check_only
class Glossary(typing_extensions.TypedDict, total=False):
    endTime: str
    entryCount: int
    inputConfig: GlossaryInputConfig
    languageCodesSet: LanguageCodesSet
    languagePair: LanguageCodePair
    name: str
    submitTime: str

@typing.type_check_only
class GlossaryInputConfig(typing_extensions.TypedDict, total=False):
    gcsSource: GcsSource

@typing.type_check_only
class InputConfig(typing_extensions.TypedDict, total=False):
    gcsSource: GcsSource
    mimeType: str

@typing.type_check_only
class LanguageCodePair(typing_extensions.TypedDict, total=False):
    sourceLanguageCode: str
    targetLanguageCode: str

@typing.type_check_only
class LanguageCodesSet(typing_extensions.TypedDict, total=False):
    languageCodes: _list[str]

@typing.type_check_only
class ListGlossariesResponse(typing_extensions.TypedDict, total=False):
    glossaries: _list[Glossary]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OutputConfig(typing_extensions.TypedDict, total=False):
    gcsDestination: GcsDestination

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class SupportedLanguage(typing_extensions.TypedDict, total=False):
    displayName: str
    languageCode: str
    supportSource: bool
    supportTarget: bool

@typing.type_check_only
class SupportedLanguages(typing_extensions.TypedDict, total=False):
    languages: _list[SupportedLanguage]

@typing.type_check_only
class TranslateDocumentRequest(typing_extensions.TypedDict, total=False):
    customizedAttribution: str
    documentInputConfig: DocumentInputConfig
    documentOutputConfig: DocumentOutputConfig
    glossaryConfig: TranslateTextGlossaryConfig
    labels: dict[str, typing.Any]
    model: str
    sourceLanguageCode: str
    targetLanguageCode: str

@typing.type_check_only
class TranslateDocumentResponse(typing_extensions.TypedDict, total=False):
    documentTranslation: DocumentTranslation
    glossaryConfig: TranslateTextGlossaryConfig
    glossaryDocumentTranslation: DocumentTranslation
    model: str

@typing.type_check_only
class TranslateTextGlossaryConfig(typing_extensions.TypedDict, total=False):
    glossary: str
    ignoreCase: bool

@typing.type_check_only
class TranslateTextRequest(typing_extensions.TypedDict, total=False):
    contents: _list[str]
    glossaryConfig: TranslateTextGlossaryConfig
    labels: dict[str, typing.Any]
    mimeType: str
    model: str
    sourceLanguageCode: str
    targetLanguageCode: str

@typing.type_check_only
class TranslateTextResponse(typing_extensions.TypedDict, total=False):
    glossaryTranslations: _list[Translation]
    translations: _list[Translation]

@typing.type_check_only
class Translation(typing_extensions.TypedDict, total=False):
    detectedLanguageCode: str
    glossaryConfig: TranslateTextGlossaryConfig
    model: str
    translatedText: str

@typing.type_check_only
class WaitOperationRequest(typing_extensions.TypedDict, total=False):
    timeout: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Address(typing_extensions.TypedDict, total=False):
    addressLine1: str
    addressLine2: str
    addressLine3: str
    contactName: str
    countryCode: str
    kind: str
    locality: str
    organizationName: str
    postalCode: str
    region: str

@typing.type_check_only
class ChangePlanRequest(typing_extensions.TypedDict, total=False):
    dealCode: str
    kind: str
    planName: str
    purchaseOrderId: str
    seats: Seats

@typing.type_check_only
class Customer(typing_extensions.TypedDict, total=False):
    alternateEmail: str
    customerDomain: str
    customerDomainVerified: bool
    customerId: str
    customerType: typing_extensions.Literal["customerTypeUnspecified", "domain", "team"]
    kind: str
    phoneNumber: str
    postalAddress: Address
    primaryAdmin: PrimaryAdmin
    resourceUiUrl: str

@typing.type_check_only
class PrimaryAdmin(typing_extensions.TypedDict, total=False):
    primaryEmail: str

@typing.type_check_only
class RenewalSettings(typing_extensions.TypedDict, total=False):
    kind: str
    renewalType: str

@typing.type_check_only
class ResellernotifyGetwatchdetailsResponse(typing_extensions.TypedDict, total=False):
    serviceAccountEmailAddresses: _list[str]
    topicName: str

@typing.type_check_only
class ResellernotifyResource(typing_extensions.TypedDict, total=False):
    topicName: str

@typing.type_check_only
class Seats(typing_extensions.TypedDict, total=False):
    kind: str
    licensedNumberOfSeats: int
    maximumNumberOfSeats: int
    numberOfSeats: int

@typing.type_check_only
class Subscription(typing_extensions.TypedDict, total=False):
    billingMethod: str
    creationTime: str
    customerDomain: str
    customerId: str
    dealCode: str
    kind: str
    plan: dict[str, typing.Any]
    purchaseOrderId: str
    renewalSettings: RenewalSettings
    resourceUiUrl: str
    seats: Seats
    skuId: str
    skuName: str
    status: str
    subscriptionId: str
    suspensionReasons: _list[str]
    transferInfo: dict[str, typing.Any]
    trialSettings: dict[str, typing.Any]

@typing.type_check_only
class Subscriptions(typing_extensions.TypedDict, total=False):
    kind: str
    nextPageToken: str
    subscriptions: _list[Subscription]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AggregationInfo(typing_extensions.TypedDict, total=False):
    aggregationCount: int
    aggregationInterval: typing_extensions.Literal[
        "AGGREGATION_INTERVAL_UNSPECIFIED", "DAILY", "MONTHLY"
    ]
    aggregationLevel: typing_extensions.Literal[
        "AGGREGATION_LEVEL_UNSPECIFIED", "ACCOUNT", "PROJECT"
    ]

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class BillingAccount(typing_extensions.TypedDict, total=False):
    displayName: str
    masterBillingAccount: str
    name: str
    open: bool

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Category(typing_extensions.TypedDict, total=False):
    resourceFamily: str
    resourceGroup: str
    serviceDisplayName: str
    usageType: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GeoTaxonomy(typing_extensions.TypedDict, total=False):
    regions: _list[str]
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "GLOBAL", "REGIONAL", "MULTI_REGIONAL"
    ]

@typing.type_check_only
class ListBillingAccountsResponse(typing_extensions.TypedDict, total=False):
    billingAccounts: _list[BillingAccount]
    nextPageToken: str

@typing.type_check_only
class ListProjectBillingInfoResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    projectBillingInfo: _list[ProjectBillingInfo]

@typing.type_check_only
class ListServicesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    services: _list[Service]

@typing.type_check_only
class ListSkusResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    skus: _list[Sku]

@typing.type_check_only
class Money(typing_extensions.TypedDict, total=False):
    currencyCode: str
    nanos: int
    units: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class PricingExpression(typing_extensions.TypedDict, total=False):
    baseUnit: str
    baseUnitConversionFactor: float
    baseUnitDescription: str
    displayQuantity: float
    tieredRates: _list[TierRate]
    usageUnit: str
    usageUnitDescription: str

@typing.type_check_only
class PricingInfo(typing_extensions.TypedDict, total=False):
    aggregationInfo: AggregationInfo
    currencyConversionRate: float
    effectiveTime: str
    pricingExpression: PricingExpression
    summary: str

@typing.type_check_only
class ProjectBillingInfo(typing_extensions.TypedDict, total=False):
    billingAccountName: str
    billingEnabled: bool
    name: str
    projectId: str

@typing.type_check_only
class Service(typing_extensions.TypedDict, total=False):
    businessEntityName: str
    displayName: str
    name: str
    serviceId: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Sku(typing_extensions.TypedDict, total=False):
    category: Category
    description: str
    geoTaxonomy: GeoTaxonomy
    name: str
    pricingInfo: _list[PricingInfo]
    serviceProviderName: str
    serviceRegions: _list[str]
    skuId: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TierRate(typing_extensions.TypedDict, total=False):
    startUsageAmount: float
    unitPrice: Money



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudResourcesettingsV1ListSettingsResponse(
    typing_extensions.TypedDict, total=False
):
    nextPageToken: str
    settings: _list[GoogleCloudResourcesettingsV1Setting]

@typing.type_check_only
class GoogleCloudResourcesettingsV1Setting(typing_extensions.TypedDict, total=False):
    effectiveValue: GoogleCloudResourcesettingsV1Value
    etag: str
    localValue: GoogleCloudResourcesettingsV1Value
    metadata: GoogleCloudResourcesettingsV1SettingMetadata
    name: str

@typing.type_check_only
class GoogleCloudResourcesettingsV1SettingMetadata(
    typing_extensions.TypedDict, total=False
):
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "BOOLEAN",
        "STRING",
        "STRING_SET",
        "ENUM_VALUE",
        "DURATION_VALUE",
        "STRING_MAP",
    ]
    defaultValue: GoogleCloudResourcesettingsV1Value
    description: str
    displayName: str
    readOnly: bool

@typing.type_check_only
class GoogleCloudResourcesettingsV1Value(typing_extensions.TypedDict, total=False):
    booleanValue: bool
    durationValue: str
    enumValue: GoogleCloudResourcesettingsV1ValueEnumValue
    stringMapValue: GoogleCloudResourcesettingsV1ValueStringMap
    stringSetValue: GoogleCloudResourcesettingsV1ValueStringSet
    stringValue: str

@typing.type_check_only
class GoogleCloudResourcesettingsV1ValueEnumValue(
    typing_extensions.TypedDict, total=False
):
    value: str

@typing.type_check_only
class GoogleCloudResourcesettingsV1ValueStringMap(
    typing_extensions.TypedDict, total=False
):
    mappings: dict[str, typing.Any]

@typing.type_check_only
class GoogleCloudResourcesettingsV1ValueStringSet(
    typing_extensions.TypedDict, total=False
):
    values: _list[str]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudEssentialcontactsV1ComputeContactsResponse(
    typing_extensions.TypedDict, total=False
):
    contacts: _list[GoogleCloudEssentialcontactsV1Contact]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudEssentialcontactsV1Contact(typing_extensions.TypedDict, total=False):
    email: str
    languageTag: str
    name: str
    notificationCategorySubscriptions: _list[str]
    validateTime: str
    validationState: typing_extensions.Literal[
        "VALIDATION_STATE_UNSPECIFIED", "VALID", "INVALID"
    ]

@typing.type_check_only
class GoogleCloudEssentialcontactsV1ListContactsResponse(
    typing_extensions.TypedDict, total=False
):
    contacts: _list[GoogleCloudEssentialcontactsV1Contact]
    nextPageToken: str

@typing.type_check_only
class GoogleCloudEssentialcontactsV1SendTestMessageRequest(
    typing_extensions.TypedDict, total=False
):
    contacts: _list[str]
    notificationCategory: typing_extensions.Literal[
        "NOTIFICATION_CATEGORY_UNSPECIFIED",
        "ALL",
        "SUSPENSION",
        "SECURITY",
        "TECHNICAL",
        "BILLING",
        "LEGAL",
        "PRODUCT_UPDATES",
        "TECHNICAL_INCIDENTS",
    ]

@typing.type_check_only
class GoogleProtobufEmpty(typing_extensions.TypedDict, total=False): ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class CloudDebuggerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ControllerResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DebuggeesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class BreakpointsResource(googleapiclient.discovery.Resource):
                def list(
                    self,
                    *,
                    debuggeeId: str,
                    agentId: str = ...,
                    successOnTimeout: bool = ...,
                    waitToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListActiveBreakpointsResponseHttpRequest: ...
                def update(
                    self,
                    *,
                    debuggeeId: str,
                    id: str,
                    body: UpdateActiveBreakpointRequest = ...,
                    **kwargs: typing.Any
                ) -> UpdateActiveBreakpointResponseHttpRequest: ...

            def register(
                self, *, body: RegisterDebuggeeRequest = ..., **kwargs: typing.Any
            ) -> RegisterDebuggeeResponseHttpRequest: ...
            def breakpoints(self) -> BreakpointsResource: ...

        def debuggees(self) -> DebuggeesResource: ...

    @typing.type_check_only
    class DebuggerResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DebuggeesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class BreakpointsResource(googleapiclient.discovery.Resource):
                def delete(
                    self,
                    *,
                    debuggeeId: str,
                    breakpointId: str,
                    clientVersion: str = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self,
                    *,
                    debuggeeId: str,
                    breakpointId: str,
                    clientVersion: str = ...,
                    **kwargs: typing.Any
                ) -> GetBreakpointResponseHttpRequest: ...
                def list(
                    self,
                    *,
                    debuggeeId: str,
                    action_value: typing_extensions.Literal["CAPTURE", "LOG"] = ...,
                    clientVersion: str = ...,
                    includeAllUsers: bool = ...,
                    includeInactive: bool = ...,
                    stripResults: bool = ...,
                    waitToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListBreakpointsResponseHttpRequest: ...
                def set(
                    self,
                    *,
                    debuggeeId: str,
                    body: Breakpoint = ...,
                    canaryOption: typing_extensions.Literal[
                        "CANARY_OPTION_UNSPECIFIED",
                        "CANARY_OPTION_TRY_ENABLE",
                        "CANARY_OPTION_TRY_DISABLE",
                    ] = ...,
                    clientVersion: str = ...,
                    **kwargs: typing.Any
                ) -> SetBreakpointResponseHttpRequest: ...

            def list(
                self,
                *,
                clientVersion: str = ...,
                includeInactive: bool = ...,
                project: str = ...,
                **kwargs: typing.Any
            ) -> ListDebuggeesResponseHttpRequest: ...
            def breakpoints(self) -> BreakpointsResource: ...

        def debuggees(self) -> DebuggeesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def controller(self) -> ControllerResource: ...
    def debugger(self) -> DebuggerResource: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GetBreakpointResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GetBreakpointResponse: ...

@typing.type_check_only
class ListActiveBreakpointsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListActiveBreakpointsResponse: ...

@typing.type_check_only
class ListBreakpointsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListBreakpointsResponse: ...

@typing.type_check_only
class ListDebuggeesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDebuggeesResponse: ...

@typing.type_check_only
class RegisterDebuggeeResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RegisterDebuggeeResponse: ...

@typing.type_check_only
class SetBreakpointResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SetBreakpointResponse: ...

@typing.type_check_only
class UpdateActiveBreakpointResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UpdateActiveBreakpointResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class DirectoryList(typing_extensions.TypedDict, total=False):
    discoveryVersion: str
    items: _list[dict[str, typing.Any]]
    kind: str

AlternativeJsonSchema = typing_extensions.TypedDict(
    "AlternativeJsonSchema",
    {
        "$ref": str,
        "additionalProperties": JsonSchema,
        "annotations": dict[str, typing.Any],
        "default": str,
        "description": str,
        "enum": _list[str],
        "enumDescriptions": _list[str],
        "format": str,
        "id": str,
        "items": JsonSchema,
        "location": str,
        "maximum": str,
        "minimum": str,
        "pattern": str,
        "properties": dict[str, typing.Any],
        "readOnly": bool,
        "repeated": bool,
        "required": bool,
        "type": str,
        "variant": dict[str, typing.Any],
    },
    total=False,
)

@typing.type_check_only
class JsonSchema(AlternativeJsonSchema): ...

@typing.type_check_only
class RestDescription(typing_extensions.TypedDict, total=False):
    auth: dict[str, typing.Any]
    basePath: str
    baseUrl: str
    batchPath: str
    canonicalName: str
    description: str
    discoveryVersion: str
    documentationLink: str
    etag: str
    exponentialBackoffDefault: bool
    features: _list[str]
    icons: dict[str, typing.Any]
    id: str
    kind: str
    labels: _list[str]
    methods: dict[str, typing.Any]
    name: str
    ownerDomain: str
    ownerName: str
    packagePath: str
    parameters: dict[str, typing.Any]
    protocol: str
    resources: dict[str, typing.Any]
    revision: str
    rootUrl: str
    schemas: dict[str, typing.Any]
    servicePath: str
    title: str
    version: str
    version_module: bool

@typing.type_check_only
class RestMethod(typing_extensions.TypedDict, total=False):
    description: str
    etagRequired: bool
    flatPath: str
    httpMethod: str
    id: str
    mediaUpload: dict[str, typing.Any]
    parameterOrder: _list[str]
    parameters: dict[str, typing.Any]
    path: str
    request: dict[str, typing.Any]
    response: dict[str, typing.Any]
    scopes: _list[str]
    supportsMediaDownload: bool
    supportsMediaUpload: bool
    supportsSubscription: bool
    useMediaDownloadService: bool

@typing.type_check_only
class RestResource(typing_extensions.TypedDict, total=False):
    methods: dict[str, typing.Any]
    resources: dict[str, typing.Any]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Action(typing_extensions.TypedDict, total=False):
    actor: Actor
    detail: ActionDetail
    target: Target
    timeRange: TimeRange
    timestamp: str

@typing.type_check_only
class ActionDetail(typing_extensions.TypedDict, total=False):
    appliedLabelChange: AppliedLabelChange
    comment: Comment
    create: Create
    delete: Delete
    dlpChange: DataLeakPreventionChange
    edit: Edit
    move: Move
    permissionChange: PermissionChange
    reference: ApplicationReference
    rename: Rename
    restore: Restore
    settingsChange: SettingsChange

@typing.type_check_only
class Actor(typing_extensions.TypedDict, total=False):
    administrator: Administrator
    anonymous: AnonymousUser
    impersonation: Impersonation
    system: SystemEvent
    user: User

@typing.type_check_only
class Administrator(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class AnonymousUser(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Anyone(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ApplicationReference(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["UNSPECIFIED_REFERENCE_TYPE", "LINK", "DISCUSS"]

@typing.type_check_only
class AppliedLabelChange(typing_extensions.TypedDict, total=False):
    changes: _list[AppliedLabelChangeDetail]

@typing.type_check_only
class AppliedLabelChangeDetail(typing_extensions.TypedDict, total=False):
    fieldChanges: _list[FieldValueChange]
    label: str
    title: str
    types: _list[str]

@typing.type_check_only
class Assignment(typing_extensions.TypedDict, total=False):
    assignedUser: User
    subtype: typing_extensions.Literal[
        "SUBTYPE_UNSPECIFIED",
        "ADDED",
        "DELETED",
        "REPLY_ADDED",
        "REPLY_DELETED",
        "RESOLVED",
        "REOPENED",
        "REASSIGNED",
    ]

@typing.type_check_only
class Comment(typing_extensions.TypedDict, total=False):
    assignment: Assignment
    mentionedUsers: _list[User]
    post: Post
    suggestion: Suggestion

@typing.type_check_only
class ConsolidationStrategy(typing_extensions.TypedDict, total=False):
    legacy: Legacy
    none: NoConsolidation

@typing.type_check_only
class Copy(typing_extensions.TypedDict, total=False):
    originalObject: TargetReference

@typing.type_check_only
class Create(typing_extensions.TypedDict, total=False):
    copy: Copy
    new: New
    upload: Upload

@typing.type_check_only
class DataLeakPreventionChange(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "FLAGGED", "CLEARED"]

@typing.type_check_only
class Date(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class Delete(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "TRASH", "PERMANENT_DELETE"]

@typing.type_check_only
class DeletedUser(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Domain(typing_extensions.TypedDict, total=False):
    legacyId: str
    name: str

@typing.type_check_only
class Drive(typing_extensions.TypedDict, total=False):
    name: str
    root: DriveItem
    title: str

@typing.type_check_only
class DriveActivity(typing_extensions.TypedDict, total=False):
    actions: _list[Action]
    actors: _list[Actor]
    primaryActionDetail: ActionDetail
    targets: _list[Target]
    timeRange: TimeRange
    timestamp: str

@typing.type_check_only
class DriveFile(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DriveFolder(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "MY_DRIVE_ROOT", "SHARED_DRIVE_ROOT", "STANDARD_FOLDER"
    ]

@typing.type_check_only
class DriveItem(typing_extensions.TypedDict, total=False):
    driveFile: DriveFile
    driveFolder: DriveFolder
    file: File
    folder: Folder
    mimeType: str
    name: str
    owner: Owner
    title: str

@typing.type_check_only
class DriveItemReference(typing_extensions.TypedDict, total=False):
    driveFile: DriveFile
    driveFolder: DriveFolder
    file: File
    folder: Folder
    name: str
    title: str

@typing.type_check_only
class DriveReference(typing_extensions.TypedDict, total=False):
    name: str
    title: str

@typing.type_check_only
class Edit(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FieldValue(typing_extensions.TypedDict, total=False):
    date: Date
    integer: Integer
    selection: Selection
    selectionList: SelectionList
    text: Text
    textList: TextList
    user: SingleUser
    userList: UserList

@typing.type_check_only
class FieldValueChange(typing_extensions.TypedDict, total=False):
    displayName: str
    fieldId: str
    newValue: FieldValue
    oldValue: FieldValue

@typing.type_check_only
class File(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class FileComment(typing_extensions.TypedDict, total=False):
    legacyCommentId: str
    legacyDiscussionId: str
    linkToDiscussion: str
    parent: DriveItem

@typing.type_check_only
class Folder(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "MY_DRIVE_ROOT", "TEAM_DRIVE_ROOT", "STANDARD_FOLDER"
    ]

@typing.type_check_only
class Group(typing_extensions.TypedDict, total=False):
    email: str
    title: str

@typing.type_check_only
class Impersonation(typing_extensions.TypedDict, total=False):
    impersonatedUser: User

@typing.type_check_only
class Integer(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class KnownUser(typing_extensions.TypedDict, total=False):
    isCurrentUser: bool
    personName: str

@typing.type_check_only
class Legacy(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Move(typing_extensions.TypedDict, total=False):
    addedParents: _list[TargetReference]
    removedParents: _list[TargetReference]

@typing.type_check_only
class New(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class NoConsolidation(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Owner(typing_extensions.TypedDict, total=False):
    domain: Domain
    drive: DriveReference
    teamDrive: TeamDriveReference
    user: User

@typing.type_check_only
class Permission(typing_extensions.TypedDict, total=False):
    allowDiscovery: bool
    anyone: Anyone
    domain: Domain
    group: Group
    role: typing_extensions.Literal[
        "ROLE_UNSPECIFIED",
        "OWNER",
        "ORGANIZER",
        "FILE_ORGANIZER",
        "EDITOR",
        "COMMENTER",
        "VIEWER",
        "PUBLISHED_VIEWER",
    ]
    user: User

@typing.type_check_only
class PermissionChange(typing_extensions.TypedDict, total=False):
    addedPermissions: _list[Permission]
    removedPermissions: _list[Permission]

@typing.type_check_only
class Post(typing_extensions.TypedDict, total=False):
    subtype: typing_extensions.Literal[
        "SUBTYPE_UNSPECIFIED",
        "ADDED",
        "DELETED",
        "REPLY_ADDED",
        "REPLY_DELETED",
        "RESOLVED",
        "REOPENED",
    ]

@typing.type_check_only
class QueryDriveActivityRequest(typing_extensions.TypedDict, total=False):
    ancestorName: str
    consolidationStrategy: ConsolidationStrategy
    filter: str
    itemName: str
    pageSize: int
    pageToken: str

@typing.type_check_only
class QueryDriveActivityResponse(typing_extensions.TypedDict, total=False):
    activities: _list[DriveActivity]
    nextPageToken: str

@typing.type_check_only
class Rename(typing_extensions.TypedDict, total=False):
    newTitle: str
    oldTitle: str

@typing.type_check_only
class Restore(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["TYPE_UNSPECIFIED", "UNTRASH"]

@typing.type_check_only
class RestrictionChange(typing_extensions.TypedDict, total=False):
    feature: typing_extensions.Literal[
        "FEATURE_UNSPECIFIED",
        "SHARING_OUTSIDE_DOMAIN",
        "DIRECT_SHARING",
        "ITEM_DUPLICATION",
        "DRIVE_FILE_STREAM",
    ]
    newRestriction: typing_extensions.Literal[
        "RESTRICTION_UNSPECIFIED", "UNRESTRICTED", "FULLY_RESTRICTED"
    ]

@typing.type_check_only
class Selection(typing_extensions.TypedDict, total=False):
    displayName: str
    value: str

@typing.type_check_only
class SelectionList(typing_extensions.TypedDict, total=False):
    values: _list[Selection]

@typing.type_check_only
class SettingsChange(typing_extensions.TypedDict, total=False):
    restrictionChanges: _list[RestrictionChange]

@typing.type_check_only
class SingleUser(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class Suggestion(typing_extensions.TypedDict, total=False):
    subtype: typing_extensions.Literal[
        "SUBTYPE_UNSPECIFIED",
        "ADDED",
        "DELETED",
        "REPLY_ADDED",
        "REPLY_DELETED",
        "ACCEPTED",
        "REJECTED",
        "ACCEPT_DELETED",
        "REJECT_DELETED",
    ]

@typing.type_check_only
class SystemEvent(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "USER_DELETION", "TRASH_AUTO_PURGE"
    ]

@typing.type_check_only
class Target(typing_extensions.TypedDict, total=False):
    drive: Drive
    driveItem: DriveItem
    fileComment: FileComment
    teamDrive: TeamDrive

@typing.type_check_only
class TargetReference(typing_extensions.TypedDict, total=False):
    drive: DriveReference
    driveItem: DriveItemReference
    teamDrive: TeamDriveReference

@typing.type_check_only
class TeamDrive(typing_extensions.TypedDict, total=False):
    name: str
    root: DriveItem
    title: str

@typing.type_check_only
class TeamDriveReference(typing_extensions.TypedDict, total=False):
    name: str
    title: str

@typing.type_check_only
class Text(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class TextList(typing_extensions.TypedDict, total=False):
    values: _list[Text]

@typing.type_check_only
class TimeRange(typing_extensions.TypedDict, total=False):
    endTime: str
    startTime: str

@typing.type_check_only
class UnknownUser(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Upload(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class User(typing_extensions.TypedDict, total=False):
    deletedUser: DeletedUser
    knownUser: KnownUser
    unknownUser: UnknownUser

@typing.type_check_only
class UserList(typing_extensions.TypedDict, total=False):
    values: _list[SingleUser]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class DoubleClickBidManagerResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class QueriesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ReportsResource(googleapiclient.discovery.Resource):
            def get(
                self, *, queryId: str, reportId: str, **kwargs: typing.Any
            ) -> ReportHttpRequest: ...
            def list(
                self,
                *,
                queryId: str,
                orderBy: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListReportsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListReportsResponseHttpRequest,
                previous_response: ListReportsResponse,
            ) -> ListReportsResponseHttpRequest | None: ...

        def create(
            self, *, body: Query = ..., **kwargs: typing.Any
        ) -> QueryHttpRequest: ...
        def delete(
            self, *, queryId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(self, *, queryId: str, **kwargs: typing.Any) -> QueryHttpRequest: ...
        def list(
            self,
            *,
            orderBy: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListQueriesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListQueriesResponseHttpRequest,
            previous_response: ListQueriesResponse,
        ) -> ListQueriesResponseHttpRequest | None: ...
        def run(
            self,
            *,
            queryId: str,
            body: RunQueryRequest = ...,
            synchronous: bool = ...,
            **kwargs: typing.Any
        ) -> ReportHttpRequest: ...
        def reports(self) -> ReportsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def queries(self) -> QueriesResource: ...

@typing.type_check_only
class ListQueriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListQueriesResponse: ...

@typing.type_check_only
class ListReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReportsResponse: ...

@typing.type_check_only
class QueryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Query: ...

@typing.type_check_only
class ReportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Report: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Answer(typing_extensions.TypedDict, total=False):
    fileUploadAnswers: FileUploadAnswers
    grade: Grade
    questionId: str
    textAnswers: TextAnswers

@typing.type_check_only
class BatchUpdateFormRequest(typing_extensions.TypedDict, total=False):
    includeFormInResponse: bool
    requests: _list[Request]
    writeControl: WriteControl

@typing.type_check_only
class BatchUpdateFormResponse(typing_extensions.TypedDict, total=False):
    form: Form
    replies: _list[Response]
    writeControl: WriteControl

@typing.type_check_only
class ChoiceQuestion(typing_extensions.TypedDict, total=False):
    options: _list[Option]
    shuffle: bool
    type: typing_extensions.Literal[
        "CHOICE_TYPE_UNSPECIFIED", "RADIO", "CHECKBOX", "DROP_DOWN"
    ]

@typing.type_check_only
class CloudPubsubTopic(typing_extensions.TypedDict, total=False):
    topicName: str

@typing.type_check_only
class CorrectAnswer(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class CorrectAnswers(typing_extensions.TypedDict, total=False):
    answers: _list[CorrectAnswer]

@typing.type_check_only
class CreateItemRequest(typing_extensions.TypedDict, total=False):
    item: Item
    location: Location

@typing.type_check_only
class CreateItemResponse(typing_extensions.TypedDict, total=False):
    itemId: str
    questionId: _list[str]

@typing.type_check_only
class CreateWatchRequest(typing_extensions.TypedDict, total=False):
    watch: Watch
    watchId: str

@typing.type_check_only
class DateQuestion(typing_extensions.TypedDict, total=False):
    includeTime: bool
    includeYear: bool

@typing.type_check_only
class DeleteItemRequest(typing_extensions.TypedDict, total=False):
    location: Location

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ExtraMaterial(typing_extensions.TypedDict, total=False):
    link: TextLink
    video: VideoLink

@typing.type_check_only
class Feedback(typing_extensions.TypedDict, total=False):
    material: _list[ExtraMaterial]
    text: str

@typing.type_check_only
class FileUploadAnswer(typing_extensions.TypedDict, total=False):
    fileId: str
    fileName: str
    mimeType: str

@typing.type_check_only
class FileUploadAnswers(typing_extensions.TypedDict, total=False):
    answers: _list[FileUploadAnswer]

@typing.type_check_only
class FileUploadQuestion(typing_extensions.TypedDict, total=False):
    folderId: str
    maxFileSize: str
    maxFiles: int
    types: _list[str]

@typing.type_check_only
class Form(typing_extensions.TypedDict, total=False):
    formId: str
    info: Info
    items: _list[Item]
    linkedSheetId: str
    responderUri: str
    revisionId: str
    settings: FormSettings

@typing.type_check_only
class FormResponse(typing_extensions.TypedDict, total=False):
    answers: dict[str, typing.Any]
    createTime: str
    formId: str
    lastSubmittedTime: str
    respondentEmail: str
    responseId: str
    totalScore: float

@typing.type_check_only
class FormSettings(typing_extensions.TypedDict, total=False):
    quizSettings: QuizSettings

@typing.type_check_only
class Grade(typing_extensions.TypedDict, total=False):
    correct: bool
    feedback: Feedback
    score: float

@typing.type_check_only
class Grading(typing_extensions.TypedDict, total=False):
    correctAnswers: CorrectAnswers
    generalFeedback: Feedback
    pointValue: int
    whenRight: Feedback
    whenWrong: Feedback

@typing.type_check_only
class Grid(typing_extensions.TypedDict, total=False):
    columns: ChoiceQuestion
    shuffleQuestions: bool

@typing.type_check_only
class Image(typing_extensions.TypedDict, total=False):
    altText: str
    contentUri: str
    properties: MediaProperties
    sourceUri: str

@typing.type_check_only
class ImageItem(typing_extensions.TypedDict, total=False):
    image: Image

@typing.type_check_only
class Info(typing_extensions.TypedDict, total=False):
    description: str
    documentTitle: str
    title: str

@typing.type_check_only
class Item(typing_extensions.TypedDict, total=False):
    description: str
    imageItem: ImageItem
    itemId: str
    pageBreakItem: PageBreakItem
    questionGroupItem: QuestionGroupItem
    questionItem: QuestionItem
    textItem: TextItem
    title: str
    videoItem: VideoItem

@typing.type_check_only
class ListFormResponsesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    responses: _list[FormResponse]

@typing.type_check_only
class ListWatchesResponse(typing_extensions.TypedDict, total=False):
    watches: _list[Watch]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    index: int

@typing.type_check_only
class MediaProperties(typing_extensions.TypedDict, total=False):
    alignment: typing_extensions.Literal[
        "ALIGNMENT_UNSPECIFIED", "LEFT", "RIGHT", "CENTER"
    ]
    width: int

@typing.type_check_only
class MoveItemRequest(typing_extensions.TypedDict, total=False):
    newLocation: Location
    originalLocation: Location

@typing.type_check_only
class Option(typing_extensions.TypedDict, total=False):
    goToAction: typing_extensions.Literal[
        "GO_TO_ACTION_UNSPECIFIED", "NEXT_SECTION", "RESTART_FORM", "SUBMIT_FORM"
    ]
    goToSectionId: str
    image: Image
    isOther: bool
    value: str

@typing.type_check_only
class PageBreakItem(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Question(typing_extensions.TypedDict, total=False):
    choiceQuestion: ChoiceQuestion
    dateQuestion: DateQuestion
    fileUploadQuestion: FileUploadQuestion
    grading: Grading
    questionId: str
    required: bool
    rowQuestion: RowQuestion
    scaleQuestion: ScaleQuestion
    textQuestion: TextQuestion
    timeQuestion: TimeQuestion

@typing.type_check_only
class QuestionGroupItem(typing_extensions.TypedDict, total=False):
    grid: Grid
    image: Image
    questions: _list[Question]

@typing.type_check_only
class QuestionItem(typing_extensions.TypedDict, total=False):
    image: Image
    question: Question

@typing.type_check_only
class QuizSettings(typing_extensions.TypedDict, total=False):
    isQuiz: bool

@typing.type_check_only
class RenewWatchRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Request(typing_extensions.TypedDict, total=False):
    createItem: CreateItemRequest
    deleteItem: DeleteItemRequest
    moveItem: MoveItemRequest
    updateFormInfo: UpdateFormInfoRequest
    updateItem: UpdateItemRequest
    updateSettings: UpdateSettingsRequest

@typing.type_check_only
class Response(typing_extensions.TypedDict, total=False):
    createItem: CreateItemResponse

@typing.type_check_only
class RowQuestion(typing_extensions.TypedDict, total=False):
    title: str

@typing.type_check_only
class ScaleQuestion(typing_extensions.TypedDict, total=False):
    high: int
    highLabel: str
    low: int
    lowLabel: str

@typing.type_check_only
class TextAnswer(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class TextAnswers(typing_extensions.TypedDict, total=False):
    answers: _list[TextAnswer]

@typing.type_check_only
class TextItem(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class TextLink(typing_extensions.TypedDict, total=False):
    displayText: str
    uri: str

@typing.type_check_only
class TextQuestion(typing_extensions.TypedDict, total=False):
    paragraph: bool

@typing.type_check_only
class TimeQuestion(typing_extensions.TypedDict, total=False):
    duration: bool

@typing.type_check_only
class UpdateFormInfoRequest(typing_extensions.TypedDict, total=False):
    info: Info
    updateMask: str

@typing.type_check_only
class UpdateItemRequest(typing_extensions.TypedDict, total=False):
    item: Item
    location: Location
    updateMask: str

@typing.type_check_only
class UpdateSettingsRequest(typing_extensions.TypedDict, total=False):
    settings: FormSettings
    updateMask: str

@typing.type_check_only
class Video(typing_extensions.TypedDict, total=False):
    properties: MediaProperties
    youtubeUri: str

@typing.type_check_only
class VideoItem(typing_extensions.TypedDict, total=False):
    caption: str
    video: Video

@typing.type_check_only
class VideoLink(typing_extensions.TypedDict, total=False):
    displayText: str
    youtubeUri: str

@typing.type_check_only
class Watch(typing_extensions.TypedDict, total=False):
    createTime: str
    errorType: typing_extensions.Literal[
        "ERROR_TYPE_UNSPECIFIED",
        "PROJECT_NOT_AUTHORIZED",
        "NO_USER_ACCESS",
        "OTHER_ERRORS",
    ]
    eventType: typing_extensions.Literal[
        "EVENT_TYPE_UNSPECIFIED", "SCHEMA", "RESPONSES"
    ]
    expireTime: str
    id: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "SUSPENDED"]
    target: WatchTarget

@typing.type_check_only
class WatchTarget(typing_extensions.TypedDict, total=False):
    topic: CloudPubsubTopic

@typing.type_check_only
class WriteControl(typing_extensions.TypedDict, total=False):
    requiredRevisionId: str
    targetRevisionId: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class HangoutsChatResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class DmsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ConversationsResource(googleapiclient.discovery.Resource):
            def messages(
                self,
                *,
                parent: str,
                body: Message = ...,
                requestId: str = ...,
                threadKey: str = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...

        def messages(
            self,
            *,
            parent: str,
            body: Message = ...,
            requestId: str = ...,
            threadKey: str = ...,
            **kwargs: typing.Any
        ) -> MessageHttpRequest: ...
        def webhooks(
            self,
            *,
            parent: str,
            body: Message = ...,
            requestId: str = ...,
            threadKey: str = ...,
            **kwargs: typing.Any
        ) -> MessageHttpRequest: ...
        def conversations(self) -> ConversationsResource: ...

    @typing.type_check_only
    class MediaResource(googleapiclient.discovery.Resource):
        def download(
            self, *, resourceName: str, **kwargs: typing.Any
        ) -> MediaHttpRequest: ...
        def download_media(
            self, *, resourceName: str, **kwargs: typing.Any
        ) -> BytesHttpRequest: ...

    @typing.type_check_only
    class RoomsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class ConversationsResource(googleapiclient.discovery.Resource):
            def messages(
                self,
                *,
                parent: str,
                body: Message = ...,
                requestId: str = ...,
                threadKey: str = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...

        def messages(
            self,
            *,
            parent: str,
            body: Message = ...,
            requestId: str = ...,
            threadKey: str = ...,
            **kwargs: typing.Any
        ) -> MessageHttpRequest: ...
        def webhooks(
            self,
            *,
            parent: str,
            body: Message = ...,
            requestId: str = ...,
            threadKey: str = ...,
            **kwargs: typing.Any
        ) -> MessageHttpRequest: ...
        def conversations(self) -> ConversationsResource: ...

    @typing.type_check_only
    class SpacesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class MembersResource(googleapiclient.discovery.Resource):
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> MembershipHttpRequest: ...
            def list(
                self,
                *,
                parent: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListMembershipsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListMembershipsResponseHttpRequest,
                previous_response: ListMembershipsResponse,
            ) -> ListMembershipsResponseHttpRequest | None: ...

        @typing.type_check_only
        class MessagesResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class AttachmentsResource(googleapiclient.discovery.Resource):
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> AttachmentHttpRequest: ...

            def create(
                self,
                *,
                parent: str,
                body: Message = ...,
                requestId: str = ...,
                threadKey: str = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def delete(
                self, *, name: str, **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(self, *, name: str, **kwargs: typing.Any) -> MessageHttpRequest: ...
            def update(
                self,
                *,
                name: str,
                body: Message = ...,
                updateMask: str = ...,
                **kwargs: typing.Any
            ) -> MessageHttpRequest: ...
            def attachments(self) -> AttachmentsResource: ...

        def get(self, *, name: str, **kwargs: typing.Any) -> SpaceHttpRequest: ...
        def list(
            self, *, pageSize: int = ..., pageToken: str = ..., **kwargs: typing.Any
        ) -> ListSpacesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListSpacesResponseHttpRequest,
            previous_response: ListSpacesResponse,
        ) -> ListSpacesResponseHttpRequest | None: ...
        def webhooks(
            self,
            *,
            parent: str,
            body: Message = ...,
            requestId: str = ...,
            threadKey: str = ...,
            **kwargs: typing.Any
        ) -> MessageHttpRequest: ...
        def members(self) -> MembersResource: ...
        def messages(self) -> MessagesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def dms(self) -> DmsResource: ...
    def media(self) -> MediaResource: ...
    def rooms(self) -> RoomsResource: ...
    def spaces(self) -> SpacesResource: ...

@typing.type_check_only
class AttachmentHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Attachment: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListMembershipsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListMembershipsResponse: ...

@typing.type_check_only
class ListSpacesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListSpacesResponse: ...

@typing.type_check_only
class MediaHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Media: ...

@typing.type_check_only
class MembershipHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Membership: ...

@typing.type_check_only
class MessageHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Message: ...

@typing.type_check_only
class SpaceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Space: ...

@typing.type_check_only
class BytesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> bytes: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ConfigMapEnvSource(typing_extensions.TypedDict, total=False):
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class ConfigMapKeySelector(typing_extensions.TypedDict, total=False):
    key: str
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class ConfigMapVolumeSource(typing_extensions.TypedDict, total=False):
    defaultMode: int
    items: _list[KeyToPath]
    name: str
    optional: bool

@typing.type_check_only
class Container(typing_extensions.TypedDict, total=False):
    args: _list[str]
    command: _list[str]
    env: _list[EnvVar]
    envFrom: _list[EnvFromSource]
    image: str
    imagePullPolicy: str
    livenessProbe: Probe
    name: str
    ports: _list[ContainerPort]
    readinessProbe: Probe
    resources: ResourceRequirements
    securityContext: SecurityContext
    startupProbe: Probe
    terminationMessagePath: str
    terminationMessagePolicy: str
    volumeMounts: _list[VolumeMount]
    workingDir: str

@typing.type_check_only
class ContainerPort(typing_extensions.TypedDict, total=False):
    containerPort: int
    name: str
    protocol: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnvFromSource(typing_extensions.TypedDict, total=False):
    configMapRef: ConfigMapEnvSource
    prefix: str
    secretRef: SecretEnvSource

@typing.type_check_only
class EnvVar(typing_extensions.TypedDict, total=False):
    name: str
    value: str
    valueFrom: EnvVarSource

@typing.type_check_only
class EnvVarSource(typing_extensions.TypedDict, total=False):
    configMapKeyRef: ConfigMapKeySelector
    secretKeyRef: SecretKeySelector

@typing.type_check_only
class ExecAction(typing_extensions.TypedDict, total=False):
    command: _list[str]

@typing.type_check_only
class GRPCAction(typing_extensions.TypedDict, total=False):
    port: int
    service: str

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class HTTPGetAction(typing_extensions.TypedDict, total=False):
    host: str
    httpHeaders: _list[HTTPHeader]
    path: str
    scheme: str

@typing.type_check_only
class HTTPHeader(typing_extensions.TypedDict, total=False):
    name: str
    value: str

@typing.type_check_only
class InstanceAttemptResult(typing_extensions.TypedDict, total=False):
    exitCode: int
    status: GoogleRpcStatus

@typing.type_check_only
class InstanceSpec(typing_extensions.TypedDict, total=False):
    activeDeadlineSeconds: str
    containers: _list[Container]
    restartPolicy: str
    serviceAccountName: str
    terminationGracePeriodSeconds: str
    volumes: _list[Volume]

@typing.type_check_only
class InstanceStatus(typing_extensions.TypedDict, total=False):
    completionTime: str
    failed: int
    index: int
    lastAttemptResult: InstanceAttemptResult
    lastExitCode: int
    restarted: int
    startTime: str
    succeeded: int

@typing.type_check_only
class InstanceTemplateSpec(typing_extensions.TypedDict, total=False):
    spec: InstanceSpec

@typing.type_check_only
class Job(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: JobSpec
    status: JobStatus

@typing.type_check_only
class JobCondition(typing_extensions.TypedDict, total=False):
    lastTransitionTime: str
    message: str
    reason: str
    severity: str
    status: str
    type: str

@typing.type_check_only
class JobSpec(typing_extensions.TypedDict, total=False):
    activeDeadlineSeconds: str
    backoffLimit: int
    completions: int
    parallelism: int
    template: InstanceTemplateSpec
    ttlSecondsAfterFinished: int

@typing.type_check_only
class JobStatus(typing_extensions.TypedDict, total=False):
    active: int
    completionTime: str
    conditions: _list[JobCondition]
    failed: int
    imageDigest: str
    instances: _list[InstanceStatus]
    observedGeneration: int
    startTime: str
    succeeded: int

@typing.type_check_only
class KeyToPath(typing_extensions.TypedDict, total=False):
    key: str
    mode: int
    path: str

@typing.type_check_only
class ListJobsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Job]
    kind: str
    metadata: ListMeta
    nextPageToken: str
    unreachable: _list[str]

AlternativeListMeta = typing_extensions.TypedDict(
    "AlternativeListMeta",
    {
        "continue": str,
        "resourceVersion": str,
        "selfLink": str,
    },
    total=False,
)

@typing.type_check_only
class ListMeta(AlternativeListMeta): ...

@typing.type_check_only
class LocalObjectReference(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class ObjectMeta(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    clusterName: str
    creationTimestamp: str
    deletionGracePeriodSeconds: int
    deletionTimestamp: str
    finalizers: _list[str]
    generateName: str
    generation: int
    labels: dict[str, typing.Any]
    name: str
    namespace: str
    ownerReferences: _list[OwnerReference]
    resourceVersion: str
    selfLink: str
    uid: str

@typing.type_check_only
class OwnerReference(typing_extensions.TypedDict, total=False):
    apiVersion: str
    blockOwnerDeletion: bool
    controller: bool
    kind: str
    name: str
    uid: str

@typing.type_check_only
class Probe(typing_extensions.TypedDict, total=False):
    exec: ExecAction
    failureThreshold: int
    grpc: GRPCAction
    httpGet: HTTPGetAction
    initialDelaySeconds: int
    periodSeconds: int
    successThreshold: int
    tcpSocket: TCPSocketAction
    timeoutSeconds: int

@typing.type_check_only
class ResourceRequirements(typing_extensions.TypedDict, total=False):
    limits: dict[str, typing.Any]
    requests: dict[str, typing.Any]

@typing.type_check_only
class SecretEnvSource(typing_extensions.TypedDict, total=False):
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class SecretKeySelector(typing_extensions.TypedDict, total=False):
    key: str
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class SecretVolumeSource(typing_extensions.TypedDict, total=False):
    defaultMode: int
    items: _list[KeyToPath]
    optional: bool
    secretName: str

@typing.type_check_only
class SecurityContext(typing_extensions.TypedDict, total=False):
    runAsUser: int

@typing.type_check_only
class TCPSocketAction(typing_extensions.TypedDict, total=False):
    host: str
    port: int

@typing.type_check_only
class Volume(typing_extensions.TypedDict, total=False):
    configMap: ConfigMapVolumeSource
    name: str
    secret: SecretVolumeSource

@typing.type_check_only
class VolumeMount(typing_extensions.TypedDict, total=False):
    mountPath: str
    name: str
    readOnly: bool
    subPath: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class File(typing_extensions.TypedDict, total=False):
    createTime: str
    hashes: _list[Hash]
    name: str
    owner: str
    sizeBytes: str
    updateTime: str

@typing.type_check_only
class Hash(typing_extensions.TypedDict, total=False):
    type: typing_extensions.Literal["HASH_TYPE_UNSPECIFIED", "SHA256", "MD5"]
    value: str

@typing.type_check_only
class ListFilesResponse(typing_extensions.TypedDict, total=False):
    files: _list[File]
    nextPageToken: str

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListPackagesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    packages: _list[Package]

@typing.type_check_only
class ListRepositoriesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    repositories: _list[Repository]

@typing.type_check_only
class ListTagsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    tags: _list[Tag]

@typing.type_check_only
class ListVersionsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    versions: _list[Version]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Package(typing_extensions.TypedDict, total=False):
    createTime: str
    displayName: str
    name: str
    updateTime: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class Repository(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    format: typing_extensions.Literal[
        "FORMAT_UNSPECIFIED", "DOCKER", "MAVEN", "NPM", "APT", "YUM", "PYTHON"
    ]
    kmsKeyName: str
    labels: dict[str, typing.Any]
    name: str
    sizeBytes: str
    updateTime: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class Tag(typing_extensions.TypedDict, total=False):
    name: str
    version: str

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class Version(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    name: str
    relatedTags: _list[Tag]
    updateTime: str
